package com.hyp.web.controller.reward;

import com.hyp.common.annotation.Log;
import com.hyp.common.core.controller.BaseController;
import com.hyp.common.core.domain.AjaxResult;
import com.hyp.common.core.page.TableDataInfo;
import com.hyp.common.enums.BusinessType;
import com.hyp.system.domain.dto.ApplyInfoListDTO;
import com.hyp.system.domain.dto.ScoreInfoSaveDTO;
import com.hyp.system.domain.vo.ApplyInfoListVO;
import com.hyp.web.controller.manager.ApplyInfoListManager;
import com.hyp.web.controller.manager.ScoreInfoManager;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * packageName com.hyp.web.controller.reward
 *
 * @author wangxy
 * @version JDK 8
 * @className RewScoreInfoController
 * @date 2024/4/12
 * @description 评分
 */
@Api("评分")
@RestController
@RequestMapping("/reward/score")
public class ScoreInfoController extends BaseController {

    @Resource
    private ScoreInfoManager scoreInfoManager;

    @Resource
    private ApplyInfoListManager applyInfoListManager;


    @ApiOperation("评分列表")
    @PreAuthorize("@ss.hasPermi('reward:score:list')")
    @GetMapping("/list")
    public TableDataInfo list(ApplyInfoListDTO applyInfoListDTO) {
        startPage();
        List<ApplyInfoListVO> list = applyInfoListManager.selectApplyInfoList(applyInfoListDTO);
        return getDataTable(list);
    }

    @ApiOperation("评分保存")
    @Log(title = "评分保存", businessType = BusinessType.INSERT)
    @PostMapping("/save")
    public AjaxResult save(@Validated @RequestBody ScoreInfoSaveDTO scoreInfo) {
        return toAjax(scoreInfoManager.saveOrUpdate(scoreInfo));
    }



    @ApiOperation("评分查询")
    @GetMapping("/getScoreInfo")
    public AjaxResult getScoreInfo(@RequestParam String applyId,
                                    @RequestParam(required = false) Long createId) {
        return success(scoreInfoManager.getScoreInfo(applyId,createId));
    }

    @ApiOperation("评分提交")
    @GetMapping(value = "/submit/{applyId}")
    public AjaxResult submit(@PathVariable String applyId) {
        return toAjax(scoreInfoManager.submit(applyId));
    }









}
